# Welcome to the earthkit.maps documentation!

Geospatial visualisation tools and templates.

```{toctree}
:caption: 'Contents:'
:maxdepth: 2

API Reference <_api/earthkit.maps/index>
```

# Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
